import React, { createContext, useCallback, useEffect, useMemo, useState, } from 'react';
import AsyncStorage from '@react-native-async-storage/async-storage';
const RANDOM_KEY = '@react-native-use-persisted-state';
export const PersistedStateContext = createContext({});
const PersistedStateProvider = ({ children }) => {
    const [loading, setLoading] = useState(true);
    const [storage, setStorage] = useState({});
    useEffect(() => {
        // First init
        (async () => {
            const state = await AsyncStorage.getItem(RANDOM_KEY);
            if (state) {
                setStorage(JSON.parse(state));
            }
            setLoading(false);
        })();
    }, []);
    useEffect(() => {
        // Storage state migrate to local storage
        AsyncStorage.setItem(RANDOM_KEY, JSON.stringify(storage));
    }, [storage]);
    const setState = useCallback((key, state) => {
        setStorage((prev) => {
            return {
                ...prev,
                [key]: state,
            };
        });
    }, []);
    const clearState = useCallback((key) => {
        setStorage((prev) => {
            const temp = { ...prev };
            delete temp[key];
            return temp;
        });
    }, []);
    const state = useMemo(() => ({
        storage,
        setState: setState,
        clearState: clearState,
    }), [storage, setState, clearState]);
    return (React.createElement(PersistedStateContext.Provider, { value: state }, loading ? null : children));
};
export default PersistedStateProvider;
